# Architecture Decision Records

| ADR | Title | Status |
|-----|-------|--------|
| [ADR-0001](0001-live-tui-for-orc-run.md) | Live TUI for `orc run` | Accepted |
| [ADR-0002](0002-state-machine.md) | Git-Backed State Machine | Accepted |
